import werkzeug
import contextvars
from flask import has_request_context
from celery.signals import before_task_publish, task_prerun
from flask_login import current_user as flask_login_current_user


def setup(flask_app):
    @before_task_publish.connect(weak=False)
    def before_task_publish_handler(sender=None, headers=None, body=None, **kwargs):
        user = current_user
        headers.update(
            {
                "user_id": user.id if user else None,
            }
        )

    @task_prerun.connect(weak=False)
    def task_prerun_handler(task, task_id, args, kwargs, *_args, **_kwargs):
        user_id = task.request.user_id
        user = flask_app.login_manager.user_callback(id=user_id)
        _cv_current_user.set(user)


_cv_current_user = contextvars.ContextVar("current_user", default=None)


def get_current_user():
    if has_request_context():
        return flask_login_current_user
    else:
        return _cv_current_user.get()


current_user = werkzeug.local.LocalProxy(get_current_user)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['celery_flask_login']

package_data = \
{'': ['*']}

install_requires = \
['Flask-Login>=0.6.2,<0.7.0',
 'Flask>=2.2.2,<3.0.0',
 'celery>=5.2.7,<6.0.0',
 'pytest>=7.2.0,<8.0.0']

setup_kwargs = {
    'name': 'celery-flask-login',
    'version': '0.1.2',
    'description': '',
    'long_description': 'None',
    'author': 'David Sternlicht',
    'author_email': 'd1618033@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
